# Changelog

## [unreleased]

## [1.0.0-post1]

- Moved documentation to Read the Docs.

## [1.0.0] - 2025-09-27

- Initial release.

[unreleased]: https://github.com/taminomara/syntax-diagrams/compare/1.0.0-post1...HEAD
[1.0.0-post1]: https://github.com/taminomara/syntax-diagrams/compare/1.0.0...1.0.0-post1
[1.0.0]: https://github.com/taminomara/syntax-diagrams/releases/tag/v1.0.0
